Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1665)

Unified Diff: content/common/page_state_serialization.h

Issue 2954343005: Merge ResourceRequestBodyImpl and ResourceRequestBody. (Closed)
Patch Set: Remove comment Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/navigation_params.cc ('k') | content/common/page_state_serialization.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/page_state_serialization.h
diff --git a/content/common/page_state_serialization.h b/content/common/page_state_serialization.h
index 9c1642da0ebb8a2f88313e2da87ec24a0963f7ca..d7a0bf35d9472aab939342e70a156c623fb6ec75 100644
--- a/content/common/page_state_serialization.h
+++ b/content/common/page_state_serialization.h
@@ -13,7 +13,7 @@
#include "base/strings/nullable_string16.h"
#include "build/build_config.h"
#include "content/common/content_export.h"
-#include "content/common/resource_request_body_impl.h"
+#include "content/public/common/resource_request_body.h"
#include "third_party/WebKit/public/platform/WebHTTPBody.h"
#include "third_party/WebKit/public/platform/WebHistoryScrollRestorationType.h"
#include "third_party/WebKit/public/platform/WebReferrerPolicy.h"
@@ -25,7 +25,7 @@ namespace content {
struct CONTENT_EXPORT ExplodedHttpBody {
base::NullableString16 http_content_type;
- scoped_refptr<ResourceRequestBodyImpl> request_body;
+ scoped_refptr<ResourceRequestBody> request_body;
bool contains_passwords;
ExplodedHttpBody();
@@ -82,15 +82,14 @@ CONTENT_EXPORT bool DecodePageStateWithDeviceScaleFactorForTesting(
ExplodedPageState* exploded);
// Converts results of EncodeResourceRequestBody (passed in as a pair of |data|
// + |size|) back into a ResourceRequestBodyImpl. Returns nullptr if the
// decoding fails (e.g. if |data| is malformed).
-scoped_refptr<ResourceRequestBodyImpl> DecodeResourceRequestBody(
- const char* data,
- size_t size);
+scoped_refptr<ResourceRequestBody> DecodeResourceRequestBody(const char* data,
+ size_t size);
// Encodes |resource_request_body| into |encoded|.
std::string EncodeResourceRequestBody(
- const ResourceRequestBodyImpl& resource_request_body);
+ const ResourceRequestBody& resource_request_body);
#endif
} // namespace content
« no previous file with comments | « content/common/navigation_params.cc ('k') | content/common/page_state_serialization.cc » ('j') | no next file with comments »
@@ -82,15 +82,14 @@ CONTENT_EXPORT bool DecodePageStateWithDeviceScaleFactorForTesting(
ExplodedPageState* exploded);
// Converts results of EncodeResourceRequestBody (passed in as a pair of |data|
-// + |size|) back into a ResourceRequestBodyImpl. Returns nullptr if the
+// + |size|) back into a ResourceRequestBody. Returns nullptr if the
// decoding fails (e.g. if |data| is malformed).

Powered by Google App Engine
This is Rietveld 408576698